import setuptools


setuptools.setup(
	name='penis',
	version='420.6969',
	description='This is prokect penis for the pp',
	author='asarma0804',
	packages=setuptools.find_packages(),
	url='http://steam.com',
	license='HOT POTATO LICENSE',
	project_urls={
		'TheHub':'https://pornhub.com/'
			
	}
		
)